@@ -1,19 +1,16 @@
+import asyncio
 from collections import defaultdict, deque
-from datetime import timedelta
 import logging
 import uuid
 
-from tornado import gen
-import tornado.locks
-
 from .client import _get_global_client
-from .utils import log_errors
+from .utils import log_errors, TimeoutError
 from .worker import get_worker
 
 logger = logging.getLogger(__name__)
 
 
-class LockExtension(object):
+class LockExtension:
     """ An extension for the scheduler to manage Locks
 
     This adds the following routes to the scheduler
@@ -41,14 +38,14 @@ class LockExtension(object):
                 result = True
             else:
                 while name in self.ids:
-                    event = tornado.locks.Event()
+                    event = asyncio.Event()
                     self.events[name].append(event)
                     future = event.wait()
                     if timeout is not None:
-                        future = gen.with_timeout(timedelta(seconds=timeout), future)
+                        future = asyncio.wait_for(future, timeout)
                     try:
                         await future
-                    except gen.TimeoutError:
+                    except TimeoutError:
                         result = False
                         break
                     else:
@@ -74,14 +71,18 @@ class LockExtension(object):
                 del self.events[name]
 
 
-class Lock(object):
+class Lock:
     """ Distributed Centralized Lock
 
     Parameters
     ----------
-    name: string
+    name: string (optional)
         Name of the lock to acquire.  Choosing the same name allows two
-        disconnected processes to coordinate a lock.
+        disconnected processes to coordinate a lock.  If not given, a random
+        name will be generated.
+    client: Client (optional)
+        Client to use for communication with the scheduler.  If not given, the
+        default global client will be used.
 
     Examples
     --------
