@@ -32,8 +32,8 @@ except ImportError:
 import pytest
 
 import dask
-from toolz import merge, memoize, assoc
-from tornado import gen, queues
+from tlz import merge, memoize, assoc
+from tornado import gen
 from tornado.ioloop import IOLoop
 
 from . import system
@@ -429,7 +429,7 @@ async def readone(comm):
     try:
         q = _readone_queues[comm]
     except KeyError:
-        q = _readone_queues[comm] = queues.Queue()
+        q = _readone_queues[comm] = asyncio.Queue()
 
         async def background_read():
             while True:
